<?php
    
    namespace artbox\catalog\models;

    use artbox\core\behaviors\LanguageBehavior;
    use artbox\core\models\Image;
    use artbox\core\models\Language;
    use Yii;
    use yii\behaviors\TimestampBehavior;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\web\Request;
    
    /**
     * This is the model class for table "brand".
     *
     * @property integer     $id
     * @property integer     $image_id
     * @property integer     $sort
     * @property boolean     $status
     * @property integer     $created_at
     * @property integer     $updated_at
     *
     * @property Image       $image
     * @property BrandLang[] $brandLangs
     * @property Language[]  $languages
     * @property Product[]   $products
     *
     * * From language behavior *
     * @property BrandLang   $lang
     * @property BrandLang[] $langs
     * @property BrandLang   $objectLang
     * @property string      $ownerKey
     * @property string      $langKey
     * @property BrandLang[] $modelLangs
     * @property bool        $transactionStatus
     * @method string           getOwnerKey()
     * @method void             setOwnerKey( string $value )
     * @method string           getLangKey()
     * @method void             setLangKey( string $value )
     * @method ActiveQuery      getLangs()
     * @method ActiveQuery      getLang( integer $language_id )
     * @method BrandLang[]    generateLangs()
     * @method void             loadLangs( Request $request )
     * @method bool             linkLangs()
     * @method bool             saveLangs()
     * @method bool             getTransactionStatus()
     * @method bool             loadWithLangs( Request $request )
     * @method bool             saveWithLangs()
     * * End language behavior *
     * @see LanguageBehavior
     */
    class Brand extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'brand';
        }
    
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'language'  => [
                    'class' => LanguageBehavior::className(),
                ],
                'timestamp' => [
                    'class' => TimestampBehavior::className(),
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'image_id',
                        'sort',
                    ],
                    'integer',
                ],
                [
                    [ 'status' ],
                    'boolean',
                ],
                [
                    [ 'image_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Image::className(),
                    'targetAttribute' => [ 'image_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'         => Yii::t('catalog', 'ID'),
                'image_id'   => Yii::t('catalog', 'ID изображения'),
                'sort'       => Yii::t('catalog', 'Сортировка'),
                'status'     => Yii::t('catalog', 'Статус'),
                'created_at' => Yii::t('catalog', 'Создано'),
                'updated_at' => Yii::t('catalog', 'Обновлено'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getImage()
        {
            return $this->hasOne(Image::className(), [ 'id' => 'image_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getBrandLangs()
        {
            return $this->hasMany(BrandLang::className(), [ 'brand_id' => 'id' ])
                        ->inverseOf('brand');
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(Language::className(), [ 'id' => 'language_id' ])
                        ->viaTable('brand_lang', [ 'brand_id' => 'id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getProducts()
        {
            return $this->hasMany(Product::className(), [ 'brand_id' => 'id' ])
                        ->inverseOf('brand');
        }
    }
