<?php
    
    namespace artbox\catalog\models;

    use artbox\core\behaviors\SlugBehavior;
    use artbox\core\models\Alias;
    use artbox\core\models\Language;
    use Yii;
    use yii\db\ActiveRecord;

    /**
     * This is the model class for table "category_lang".
     *
     * @property integer  $category_id
     * @property integer  $language_id
     * @property string   $title
     * @property integer  $alias_id
     * @property string   $description
     * @property Alias    $alias
     * @property Category $category
     * @property Language $language
     */
    class CategoryLang extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'category_lang';
        }
    
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'slug' => [
                    'class'  => SlugBehavior::className(),
                    'action' => 'category/view',
                    'params' => [
                        'id' => 'category_id',
                    ],
                    'fields' => [
                        'title' => 'Category title',
                    ],
                ],
            ];
        }
    
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'category_id',
                        'language_id',
                        'title',
                    ],
                    'required',
                ],
                [
                    [
                        'category_id',
                        'language_id',
                        'alias_id',
                    ],
                    'integer',
                ],
                [
                    [ 'description' ],
                    'string',
                ],
                [
                    [
                        'title',
                        'aliasValue',
                    ],
                    'string',
                    'max' => 255,
                ],
                [
                    [ 'alias_id' ],
                    'unique',
                ],
                [
                    [ 'category_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Category::className(),
                    'targetAttribute' => [ 'category_id' => 'id' ],
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'id' ],
                ],
            ];
        }
    
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'category_id' => Yii::t('catalog', 'Category ID'),
                'language_id' => Yii::t('catalog', 'Language ID'),
                'title'       => Yii::t('catalog', 'Title'),
                'alias_id'    => Yii::t('catalog', 'Alias ID'),
                'description' => Yii::t('catalog', 'Description'),
            ];
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getAlias()
        {
            return $this->hasOne(Alias::className(), [ 'id' => 'alias_id' ]);
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getCategory()
        {
            return $this->hasOne(Category::className(), [ 'id' => 'category_id' ]);
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'id' => 'language_id' ]);
        }
    }
