<?php
    
    namespace artbox\catalog\models;
    
    use artbox\core\behaviors\LanguageBehavior;
    use artbox\core\models\Image;
    use Yii;
    use yii\behaviors\TimestampBehavior;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\web\Request;
    
    /**
     * This is the abstract model class for option models.
     *
     * @property integer          $id
     * @property integer          $groupId
     * @property integer          $image_id
     * @property integer          $sort
     * @property boolean          $status
     * @property integer          $created_at
     * @property integer          $updated_at
     * @property OptionGroup|null $group
     * @property Image            $image
     * * From language behavior *
     * @property OptionLang       $lang
     * @property OptionLang[]     $langs
     * @property OptionLang       $objectLang
     * @property string           $ownerKey
     * @property string           $langKey
     * @property OptionLang[]     $modelLangs
     * @property bool             $transactionStatus
     * @method string           getOwnerKey()
     * @method void             setOwnerKey( string $value )
     * @method string           getLangKey()
     * @method void             setLangKey( string $value )
     * @method ActiveQuery      getLangs()
     * @method ActiveQuery      getLang( integer $language_id )
     * @method OptionLang[]    generateLangs()
     * @method void             loadLangs( Request $request )
     * @method bool             linkLangs()
     * @method bool             saveLangs()
     * @method bool             getTransactionStatus()
     * @method bool             loadWithLangs( Request $request )
     * @method bool             saveWithLangs()
     * * End language behavior *
     * @see LanguageBehavior
     */
    abstract class Option extends ActiveRecord
    {
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'language'  => [
                    'class' => LanguageBehavior::className(),
                ],
                'timestamp' => [
                    'class' => TimestampBehavior::className(),
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'status',
                    ],
                    'boolean',
                ],
                [
                    [
                        'sort',
                        'image_id',
                    ],
                    'integer',
                ],
                [
                    [
                        'image_id',
                    ],
                    'exist',
                    'targetClass'     => Image::className(),
                    'targetAttribute' => 'id',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'         => Yii::t('catalog', 'ID'),
                'groupId'    => Yii::t('catalog', 'Group ID'),
                'image_id'   => Yii::t('catalog', 'Image ID'),
                'sort'       => Yii::t('catalog', 'Sort'),
                'status'     => Yii::t('catalog', 'Status'),
                'created_at' => Yii::t('catalog', 'Created At'),
                'updated_at' => Yii::t('catalog', 'Updated At'),
            ];
        }
        
        /**
         * Return ActiveQuery to get Image for exact Option if exist
         *
         * @return \yii\db\ActiveQuery
         */
        public function getImage()
        {
            return $this->hasOne(
                Image::className(),
                [
                    'id' => 'image_id',
                ]
            );
        }
        
        /**
         * Get exact Option Group id value
         *
         * @return int|null
         */
        abstract public function getGroupId();
        
        /**
         * Set Option Group link to Option model
         *
         * @param int $id
         *
         * @return void
         */
        abstract public function setGroupId(int $id);
        
        /**
         * Get Group query
         *
         * @return \yii\db\ActiveQuery
         */
        abstract public function getGroup(): ActiveQuery;
    }
