<?php
    
    namespace artbox\catalog\models;

    use artbox\core\behaviors\SlugBehavior;
    use artbox\core\models\Alias;
    use artbox\core\models\Language;
    use Yii;
    use yii\db\ActiveRecord;

    /**
     * This is the model class for table "product_lang".
     *
     * @property integer  $product_id
     * @property integer  $language_id
     * @property string   $title
     * @property integer  $alias_id
     * @property string   $description
     *
     * @property Alias    $alias
     * @property Language $language
     * @property Product  $product
     */
    class ProductLang extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'product_lang';
        }
    
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'slug' => [
                    'class'  => SlugBehavior::className(),
                    'action' => 'product/view',
                    'params' => [
                        'id' => 'product_id',
                    ],
                    'fields' => [
                        'title'       => \Yii::t('catalog', 'Product title'),
                        'description' => \Yii::t('catalog', 'Product description'),
                    ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'title',
                    ],
                    'required',
                ],
                [
                    [ 'description' ],
                    'string',
                ],
                [
                    [
                        'title',
                        'aliasValue',
                    ],
                    'string',
                    'max' => 255,
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'product_id'  => Yii::t('catalog', 'Product ID'),
                'language_id' => Yii::t('catalog', 'Language ID'),
                'title'       => Yii::t('catalog', 'Title'),
                'alias_id'    => Yii::t('catalog', 'Alias ID'),
                'description' => Yii::t('catalog', 'Description'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getAlias()
        {
            return $this->hasOne(Alias::className(), [ 'id' => 'alias_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'id' => 'language_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getProduct()
        {
            return $this->hasOne(Product::className(), [ 'id' => 'product_id' ])
                        ->inverseOf('productLangs');
        }
    }
