<?php
    
    namespace artbox\catalog\models;
    
    use Yii;
    use yii\db\ActiveRecord;

    /**
     * This is the model class for table "product_to_category".
     *
     * @property integer  $product_id
     * @property integer  $category_id
     *
     * @property Category $category
     * @property Product  $product
     */
    class ProductToCategory extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'product_to_category';
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'product_id',
                        'category_id',
                    ],
                    'required',
                ],
                [
                    [
                        'product_id',
                        'category_id',
                    ],
                    'integer',
                ],
                [
                    [ 'category_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Category::className(),
                    'targetAttribute' => [ 'category_id' => 'id' ],
                ],
                [
                    [ 'product_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Product::className(),
                    'targetAttribute' => [ 'product_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'product_id'  => Yii::t('catalog', 'Product ID'),
                'category_id' => Yii::t('catalog', 'Category ID'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getCategory()
        {
            return $this->hasOne(Category::className(), [ 'id' => 'category_id' ])
                        ->inverseOf('productToCategories');
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getProduct()
        {
            return $this->hasOne(Product::className(), [ 'id' => 'product_id' ])
                        ->inverseOf('productToCategories');
        }
    }
