<?php
    
    use artbox\catalog\models\Category;
    use artbox\catalog\models\CategoryLang;
    use artbox\core\components\imagemanager\components\ImageManagerInputWidget;
    use artbox\core\widgets\LanguageForm;
    use yii\helpers\Html;
    use yii\web\View;
    use yii\widgets\ActiveForm;
    use kartik\select2\Select2;
    use yii\web\JsExpression;
    
    /**
     * @var View           $this
     * @var Category       $model
     * @var CategoryLang[] $modelLangs
     */
    
    $url = \yii\helpers\Url::to([ 'category/list' ]);
    
    if ($model->isNewRecord) {
        $id = 'null';
    } else {
        $id = (string) $model->id;
    }
    
    $parent = empty($model->parent) ? '' : $model->parent->lang->title;
?>

<div class="category-form">
    
    <?php $form = ActiveForm::begin(); ?>
    
    <?= LanguageForm::widget(
        [
            'modelLangs' => $modelLangs,
            'formView'   => '@artbox/catalog/views/category/_form_language',
            'form'       => $form,
        ]
    ) ?>
    
    <?php
        echo $form->field($model, 'image_id')
                  ->widget(
                      ImageManagerInputWidget::className(),
                      [
                          'aspectRatio'                  => ( 16 / 9 ),
                          //set the aspect ratio
                          'showPreview'                  => true,
                          //false to hide the preview
                          'showDeletePickedImageConfirm' => false,
                          //on true show warning before detach image
                      ]
                  );
    ?>
    
    <?php
        echo $form->field($model, 'thumb_id')
                  ->widget(
                      ImageManagerInputWidget::className(),
                      [
                          'aspectRatio'                  => ( 16 / 9 ),
                          //set the aspect ratio
                          'showPreview'                  => true,
                          //false to hide the preview
                          'showDeletePickedImageConfirm' => false,
                          //on true show warning before detach image
                      ]
                  );
    ?>
    
    <?php
        echo $form->field($model, 'parent_id')
                  ->widget(
                      Select2::className(),
                      [
                          'initValueText' => $parent,
                          'options'       => [ 'placeholder' => \Yii::t('catalog', 'Search for a category ...') ],
                          'pluginOptions' => [
                              'allowClear'         => true,
                              'minimumInputLength' => 3,
                              'language'           => [
                                  'errorLoading' => new JsExpression(
                                      "function () { return 'Waiting for results...'; }"
                                  ),
                              ],
                              'ajax'               => [
                                  'url'      => $url,
                                  'dataType' => 'json',
                                  'data'     => new JsExpression(
                                      'function(params) { 
                                                                    return {
                                                                      q:params.term,
                                                                      id:' . $id . '
                                                                        }; 
                                                                    }'
                                  ),
                              ],
                              'escapeMarkup'       => new JsExpression('function (markup) { return markup; }'),
                              'templateResult'     => new JsExpression(
                                  'function (category) { 
                                                                        return category.text; 
                                                                      }'
                              ),
                              'templateSelection'  => new JsExpression(
                                  'function (category) {
                                                                        return category.text; 
                                                                      }'
                              ),
                          ],
                      ]
                  );
    ?>
    
    <?= $form->field($model, 'sort')
             ->textInput() ?>
    
    <?= $form->field($model, 'status')
             ->checkbox(
                 [
                     'class' => 'flat',
                 ]
             ) ?>
  
  <div class="form-group">
      <?= Html::submitButton(
          $model->isNewRecord ? Yii::t('catalog', 'Create') : Yii::t('catalog', 'Update'),
          [ 'class' => $model->isNewRecord ? 'btn btn-success' : 'btn btn-primary' ]
      ) ?>
  </div>
    
    <?php ActiveForm::end(); ?>

</div>
