<?php
    
    use artbox\catalog\models\Product;
    use artbox\catalog\models\ProductLang;
    use artbox\core\widgets\BitMaskWidget;
    use artbox\core\widgets\LanguageForm;
    use kartik\select2\Select2;
    use artbox\core\components\imagemanager\components\ImageManagerInputWidget;
    use yii\helpers\Url;
    use yii\web\JsExpression;
    use yii\web\View;
    use yii\widgets\ActiveForm;
    
    /**
     * @var ProductLang[] $modelLangs
     * @var Product       $model
     * @var ActiveForm    $form
     * @var View          $this
     */
?>

<?= $form->field($model, 'brand_id')
         ->widget(
             Select2::className(),
             [
                 'initValueText' => $model->brand_id ? $model->brand->lang->title : '',
                 'options'       => [ 'placeholder' => \Yii::t('catalog', 'Search for a brand ...') ],
                 'pluginOptions' => [
                     'allowClear'         => true,
                     'minimumInputLength' => 3,
                     'language'           => [
                         'errorLoading' => new JsExpression(
                             "function () { return 'Waiting for results...'; }"
                         ),
                     ],
                     'ajax'               => [
                         'url'      => Url::to([ '/brand/list' ]),
                         'dataType' => 'json',
                         'data'     => new JsExpression(
                             'function(params) { 
                                    return {
                                        q:params.term,
                                        limit:20
                                    }; 
                                 }'
                         ),
                     ],
                     'escapeMarkup'       => new JsExpression('function (markup) { return markup; }'),
                     'templateResult'     => new JsExpression(
                         'function (brand) { 
                                return brand.text; 
                             }'
                     ),
                     'templateSelection'  => new JsExpression(
                         'function (brand) {
                                return brand.text; 
                             }'
                     ),
                 ],
             ]
         ) ?>

<div class="form-group">
  <label class="control-label"><?= \Yii::t('catalog', 'Categories'); ?></label>
    <?php
        echo Select2::widget(
            [
                'name'          => 'categoryIds',
                'options'       => [
                    'placeholder' => \Yii::t('catalog', 'Search for a categories ...'),
                    'multiple'    => true,
                ],
                'value'         => array_keys($model->categoryIds),
                'data'          => $model->categoryIds,
                'pluginOptions' => [
                    'allowClear'         => true,
                    'minimumInputLength' => 3,
                    'language'           => [
                        'errorLoading' => new JsExpression(
                            "function () { return 'Waiting for results...'; }"
                        ),
                    ],
                    'ajax'               => [
                        'url'      => Url::to([ '/category/list' ]),
                        'dataType' => 'json',
                        'data'     => new JsExpression(
                            'function(params) { 
                                    return {
                                        q:params.term
                                    }; 
                                 }'
                        ),
                    ],
                    'escapeMarkup'       => new JsExpression(
                        'function (markup) {
                                return markup; 
                             }'
                    ),
                    'templateResult'     => new JsExpression(
                        'function (brand) { 
                                return brand.text; 
                             }'
                    ),
                    'templateSelection'  => new JsExpression(
                        'function (brand) {
                                return brand.text; 
                             }'
                    ),
                ],
            ]
        );
    ?>
</div>

<?php
    echo $form->field($model, 'image_id')
              ->widget(
                  ImageManagerInputWidget::className(),
                  [
                      'aspectRatio'                  => ( 16 / 9 ),
                      //set the aspect ratio
                      'showPreview'                  => true,
                      //false to hide the preview
                      'showDeletePickedImageConfirm' => false,
                      //on true show warning before detach image
                  ]
              );
?>

<?= BitMaskWidget::widget(
    [
        'form'  => $form,
        'model' => $model,
    ]
); ?>

<?= $form->field($model, 'video')
         ->textInput() ?>

<?= LanguageForm::widget(
    [
        'modelLangs' => $modelLangs,
        'formView'   => '@artbox/catalog/views/product/_form_language',
        'form'       => $form,
    ]
) ?>

<?= $form->field($model, 'sort')
         ->textInput() ?>

<?= $form->field($model, 'status')
         ->checkbox([ 'class' => 'flat', ]) ?>

<div class="form-group">
  <label class="control-label"><?= \Yii::t('catalog', 'Recommends'); ?></label>
    <?php
        if ($model->isNewRecord) {
            $condition = '';
        } else {
            $condition = ', id: ' . $model->id;
        }
        echo Select2::widget(
            [
                'name'          => 'recommendIds',
                'options'       => [
                    'placeholder' => \Yii::t('catalog', 'Search for products ...'),
                    'multiple'    => true,
                ],
                'value'         => array_keys($model->recommendIds),
                'data'          => $model->recommendIds,
                'pluginOptions' => [
                    'allowClear'         => true,
                    'minimumInputLength' => 3,
                    'language'           => [
                        'errorLoading' => new JsExpression(
                            "function () { return 'Waiting for results...'; }"
                        ),
                    ],
                    'ajax'               => [
                        'url'      => Url::to([ '/product/list' ]),
                        'dataType' => 'json',
                        'data'     => new JsExpression(
                            'function(params) {
                                    return {
                                        q:params.term' . $condition . '
                                    };
                                 }'
                        ),
                    ],
                    'escapeMarkup'       => new JsExpression(
                        'function (markup) {
                                return markup;
                             }'
                    ),
                    'templateResult'     => new JsExpression(
                        'function (product) {
                                return product.text;
                             }'
                    ),
                    'templateSelection'  => new JsExpression(
                        'function (product) {
                                return product.text;
                             }'
                    ),
                ],
            ]
        );
    ?>
</div>
