<?php
    
    namespace artbox\core\models;
    
    use yii\db\ActiveRecord;
    
    /**
     * This is the model class for table "page_category_lang".
     *
     * @property string       $title
     * @property integer      $language_id
     * @property integer      $page_category_id
     * @property Language     $language
     * @property PageCategory $pageCategory
     */
    class PageCategoryLang extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'page_category_lang';
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'language_id',
                        'page_category_id',
                    ],
                    'integer',
                ],
                [
                    [ 'title' ],
                    'string',
                    'max' => 255,
                ],
                [
                    [
                        'language_id',
                        'page_category_id',
                    ],
                    'unique',
                    'targetAttribute' => [
                        'language_id',
                        'page_category_id',
                    ],
                    'message'         => 'The combination of Language ID and Page Category ID has already been taken.',
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'id' ],
                ],
                [
                    [ 'page_category_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => PageCategory::className(),
                    'targetAttribute' => [ 'page_category_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'title'            => 'Title',
                'language_id'      => 'Language ID',
                'page_category_id' => 'Page Category ID',
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'id' => 'language_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getPageCategory()
        {
            return $this->hasOne(PageCategory::className(), [ 'id' => 'page_category_id' ]);
        }
    }
