<?php
    
    namespace artbox\core\models;
    
    use artbox\core\behaviors\SlugBehavior;
    use Yii;
    use yii\db\ActiveRecord;
    
    /**
     * This is the model class for table "page_lang".
     *
     * @property integer  $page_id
     * @property integer  $language_id
     * @property string   $title
     * @property string   $body
     * @property integer  $alias_id
     * @property Language $language
     * @property Page     $page
     * @property Alias    $alias
     */
    class PageLang extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function primaryKey()
        {
            return [
                'page_id',
                'language_id',
            ];
        }
        
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'page_lang';
        }
    
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'slug' => [
                    'class'  => SlugBehavior::className(),
                    'action' => 'page/view',
                    'params' => [
                        'id'   => 'page_id',
                    ],
                    'fields' => [
                        'title'           => 'Page title',
                        'page.id'         => 'Page id',
                        'body'            => 'Page body',
                        'page.lang.title' => 'Page title 2',
                    ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'title',
                        'body',
                    ],
                    'required',
                ],
                [
                    [
                        'body',
                        'aliasValue',
                    ],
                    'string',
                ],
                [
                    [
                        'title',
                        'aliasValue',
                    ],
                    'string',
                    'max' => 255,
                ],
                [
                    [
                        'page_id',
                        'language_id',
                    ],
                    'unique',
                    'targetAttribute' => [
                        'page_id',
                        'language_id',
                    ],
                    'message'         => \Yii::t(
                        'core',
                        'The combination of Page ID and Language ID has already been taken.'
                    ),
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'id' ],
                ],
                [
                    [ 'page_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Page::className(),
                    'targetAttribute' => [ 'page_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'page_id'     => Yii::t('core', 'page_id'),
                'language_id' => Yii::t('core', 'language_id'),
                'title'       => Yii::t('core', 'Title'),
                'body'        => Yii::t('core', 'Body'),
                'alias_id'    => Yii::t('core', 'Alias'),
                'aliasValue'  => Yii::t('core', 'Alias'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'id' => 'language_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getPage()
        {
            return $this->hasOne(Page::className(), [ 'id' => 'page_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getAlias()
        {
            return $this->hasOne(Alias::className(), [ 'id' => 'alias_id' ]);
        }
    }
