<?php
    
    namespace artbox\core\models;
    
    use artbox\core\behaviors\LanguageBehavior;
    use Yii;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\web\Request;
    
    /**
     * This is the model class for table "slide".
     *
     * @property integer     $id
     * @property integer     $slider_id
     * @property boolean     $status
     * @property integer     $sort
     * @property Slider      $slider
     * @property SlideLang[] $slideLangs
     * * From language behavior *
     * @property PageLang    $lang
     * @property PageLang[]  $langs
     * @property PageLang    $objectLang
     * @property string      $ownerKey
     * @property string      $langKey
     * @property PageLang[]  $modelLangs
     * @property bool        $transactionStatus
     * @method string       getOwnerKey()
     * @method void         setOwnerKey( string $value )
     * @method string       getLangKey()
     * @method void         setLangKey( string $value )
     * @method ActiveQuery  getLangs()
     * @method ActiveQuery  getLang( integer $language_id )
     * @method PageLang[]   generateLangs()
     * @method void         loadLangs( Request $request )
     * @method bool         linkLangs()
     * @method bool         saveLangs()
     * @method bool         getTransactionStatus()
     * @method bool         loadWithLangs( Request $request )
     * @method bool         saveWithLangs()
     * * End language behavior *
     * @see LanguageBehavior
     */
    class Slide extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'slide';
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'language' => [
                    'class' => LanguageBehavior::className(),
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'slider_id' ],
                    'required',
                ],
                [
                    [
                        'slider_id',
                        'sort',
                    ],
                    'integer',
                ],
                [
                    [ 'status' ],
                    'boolean',
                ],
                [
                    [ 'slider_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Slider::className(),
                    'targetAttribute' => [ 'slider_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'        => Yii::t('core', 'ID'),
                'slider_id' => Yii::t('core', 'Slider ID'),
                'status'    => Yii::t('core', 'Status'),
                'sort'      => Yii::t('core', 'Sort'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getSlider()
        {
            return $this->hasOne(Slider::className(), [ 'id' => 'slider_id' ])
                        ->inverseOf('slides');
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getSlideLangs()
        {
            return $this->hasMany(SlideLang::className(), [ 'slide_id' => 'id' ])
                        ->inverseOf('slide');
        }
    }
