<?php
    
    use artbox\core\models\Page;
    use artbox\core\models\PageLang;
    use artbox\core\widgets\LanguageForm;
    use kartik\select2\Select2;
    use yii\helpers\Url;
    use yii\web\JsExpression;
    use yii\web\View;
    use yii\widgets\ActiveForm;
    
    /**
     * @var View       $this
     * @var Page       $model
     * @var ActiveForm $form
     * @var PageLang[] $modelLangs
     */

?>

<?= LanguageForm::widget(
    [
        'modelLangs' => $modelLangs,
        'formView'   => '@artbox/core/views/page/_form_language',
        'form'       => $form,
    ]
) ?>
    
    <div class="form-group">
        <label class="control-label"><?= \Yii::t('core', 'Categories'); ?></label>
        <?php
            echo Select2::widget(
                [
                    'name'          => 'categoryIds',
                    'options'       => [
                        'placeholder' => \Yii::t('core', 'Search for a categories ...'),
                        'multiple'    => true,
                    ],
                    'value'         => array_keys($model->categoryIds),
                    'data'          => $model->categoryIds,
                    'pluginOptions' => [
                        'allowClear'         => true,
                        'minimumInputLength' => 3,
                        'language'           => [
                            'errorLoading' => new JsExpression(
                                "function () { return 'Waiting for results...'; }"
                            ),
                        ],
                        'ajax'               => [
                            'url'      => Url::to([ '/page-category/list' ]),
                            'dataType' => 'json',
                            'data'     => new JsExpression(
                                'function(params) { 
                                    return {
                                        q:params.term
                                    }; 
                                 }'
                            ),
                        ],
                        'escapeMarkup'       => new JsExpression(
                            'function (markup) {
                                return markup; 
                             }'
                        ),
                        'templateResult'     => new JsExpression(
                            'function (brand) { 
                                return brand.text; 
                             }'
                        ),
                        'templateSelection'  => new JsExpression(
                            'function (brand) {
                                return brand.text; 
                             }'
                        ),
                    ],
                ]
            );
        ?>
    </div>

<?= $form->field($model, 'in_menu')
         ->checkbox(
             [
                 'class' => 'flat',
             ]
         ) ?>

<?= $form->field($model, 'sort')
         ->input('number') ?>