<?php
    
    namespace artbox\order\models;

    use artbox\core\behaviors\LanguageBehavior;
    use artbox\core\models\Language;
    use Yii;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\web\Request;

    /**
     * This is the model class for table "payment".
     *
     * @property integer       $id
     * @property integer       $sort
     * @property boolean       $status
     * @property Order[]       $orders
     * @property PaymentLang[] $paymentLangs
     * @property Language[]    $languages
     * * From language behavior *
     * @property PaymentLang   $lang
     * @property PaymentLang[] $langs
     * @property PaymentLang   $objectLang
     * @property string        $ownerKey
     * @property string        $langKey
     * @property PaymentLang[] $modelLangs
     * @property bool          $transactionStatus
     * @method string       getOwnerKey()
     * @method void         setOwnerKey( string $value )
     * @method string       getLangKey()
     * @method void         setLangKey( string $value )
     * @method ActiveQuery  getLangs()
     * @method ActiveQuery  getLang( integer $language_id )
     * @method PaymentLang[]   generateLangs()
     * @method void         loadLangs( Request $request )
     * @method bool         linkLangs()
     * @method bool         saveLangs()
     * @method bool         getTransactionStatus()
     * @method bool         loadWithLangs( Request $request )
     * @method bool         saveWithLangs()
     * * End language behavior *
     * @see LanguageBehavior
     */
    class Payment extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'payment';
        }
    
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'language' => [
                    'class' => LanguageBehavior::className(),
                ],
            ];
        }
    
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'sort' ],
                    'integer',
                ],
                [
                    [ 'status' ],
                    'boolean',
                ],
            ];
        }
    
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'     => Yii::t('order', 'ID'),
                'sort'   => Yii::t('order', 'Sort'),
                'status' => Yii::t('order', 'Status'),
            ];
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getOrders()
        {
            return $this->hasMany(Order::className(), [ 'payment_id' => 'id' ]);
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getPaymentLangs()
        {
            return $this->hasMany(PaymentLang::className(), [ 'payment_id' => 'id' ]);
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(Language::className(), [ 'id' => 'language_id' ])
                        ->viaTable('payment_lang', [ 'payment_id' => 'id' ]);
        }
    }
