<?php
    
    namespace artbox\order\models;
    
    use artbox\core\models\Language;
    use Yii;
    use yii\db\ActiveRecord;

    /**
     * This is the model class for table "payment_lang".
     *
     * @property integer  $payment_id
     * @property integer  $language_id
     * @property string   $title
     * @property string   $description
     * @property Language $language
     * @property Payment  $payment
     */
    class PaymentLang extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'payment_lang';
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'payment_id',
                        'language_id',
                        'title',
                    ],
                    'required',
                ],
                [
                    [
                        'payment_id',
                        'language_id',
                    ],
                    'integer',
                ],
                [
                    [ 'description' ],
                    'string',
                ],
                [
                    [ 'title' ],
                    'string',
                    'max' => 255,
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'id' ],
                ],
                [
                    [ 'payment_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Payment::className(),
                    'targetAttribute' => [ 'payment_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'payment_id'  => Yii::t('order', 'Payment ID'),
                'language_id' => Yii::t('order', 'Language ID'),
                'title'       => Yii::t('order', 'Title'),
                'description' => Yii::t('order', 'Description'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'id' => 'language_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getPayment()
        {
            return $this->hasOne(Payment::className(), [ 'id' => 'payment_id' ]);
        }
    }
