<?php
    
    use yii\bootstrap\Html;
    use yii\widgets\DetailView;
    use yiister\gentelella\widgets\Panel;
    
    /* @var $this yii\web\View */
    /* @var $model artbox\order\models\Order */
    
    $this->title = $model->name;
    $this->params[ 'breadcrumbs' ][] = [
        'label' => Yii::t('order', 'Orders'),
        'url'   => [ 'index' ],
    ];
    $this->params[ 'breadcrumbs' ][] = $this->title;
?>
<div class="order-view">
    <?php
        $xPanel = Panel::begin(
            [
                'header' => $this->title,
            ]
        );
    ?>
  <p>
      <?= Html::a(
          Yii::t('order', 'Update'),
          [
              'update',
              'id' => $model->id,
          ],
          [ 'class' => 'btn btn-primary' ]
      ) ?>
      <?= Html::a(
          Yii::t('order', 'Delete'),
          [
              'delete',
              'id' => $model->id,
          ],
          [
              'class' => 'btn btn-danger',
              'data'  => [
                  'confirm' => Yii::t('order', 'Are you sure you want to delete this item?'),
                  'method'  => 'post',
              ],
          ]
      ) ?>
  </p>
    
    <?= DetailView::widget(
        [
            'model'      => $model,
            'attributes' => [
                'id',
                'user_id',
                'name',
                'phone',
                'email:email',
                'city',
                'address',
                'comment',
                'ip',
                'created_at:datetime',
                'updated_at:datetime',
                'deleted_at:datetime',
                [
                    'label'     => \Yii::t('order', 'Label'),
                    'attribute' => 'label.lang.title',
                ],
                [
                    'label'     => \Yii::t('order', 'Delivery'),
                    'attribute' => 'delivery.lang.title',
                ],
                [
                    'label'     => \Yii::t('order', 'Payment'),
                    'attribute' => 'payment.lang.title',
                ],
                [
                    'label'  => \Yii::t('order', 'Products'),
                    'value'  => function () use ($model) {
                        $items = '';
                        foreach ($model->orderProducts as $orderProduct) {
                            $sum = $orderProduct->price * $orderProduct->count;
                            $items .= Html::tag(
                                'li',
                                Html::a(
                                    $orderProduct->variant->product->lang->title . ' (' . $orderProduct->sku . ')',
                                    [
                                        'product/view',
                                        'id' => $orderProduct->variant->product->id,
                                    ],
                                    [
                                        'class'  => 'test',
                                        'target' => '_blank',
                                    ]
                                ) . ' - ' . $orderProduct->price . 'грн.' . ' * ' . $orderProduct->count . 'x = ' . $sum . 'грн.'
                            );
                        }
                        return Html::tag('ul', $items);
                    },
                    'format' => 'html',
                ],
            ],
        ]
    ) ?>
    
    <?php
        $xPanel::end();
    ?>

</div>
